##' Function to produce empty matrices to store MCMC results. 
##' @title Function to produce empty matrices to store MCMC results  
##' @param Data.list A list of K elements, where K is the number of studies, 
##' each element is an RNAseq data matrix with G rows and N 
##' columns, where G is number of genes and N is the sample size.
##' Genes are matched across all studies.
##' @param iteration The number of MCMC chains wish to run  
##' @return A list of empty store matrices for each parameter

##' @export
##' @examples
##' \dontrun{
##' iteration <- 2000
##' burnin <- 500
##' store <-Store(Data.list=Data.list, iteration=iteration) 
##' }

Store <- function(Data.list,iteration)  {
  
  G <- sapply(Data.list,nrow)[1]  # number of genes
  N <- sapply(Data.list,ncol)    # number of samples
  K <- length(Data.list) # number of studies
  delta <- matrix(rep(0, K*G*iteration),nrow=K*G,ncol=iteration)   
  beta<-matrix(rep(0,K*G*iteration),nrow=K*G,ncol=iteration)
    
  store <- list(Delta=delta,
                Beta=beta)
  print("Store matrix is ready")
  return(store)
}
