% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/DPM.R
\name{DPM}
\alias{DPM}
\title{Function to run DPM part of the model}
\usage{
DPM(Beta.obs, Delta, iteration, thin, C.init = 10, pi.alpha = 2,
  seed = 12345)
}
\arguments{
\item{Beta.obs}{A matrix of observed effect size, with
G rows and K columns , where K is the number of studies.}

\item{Delta}{A matrix of delta output from \code{MCMCRun}, with
G*K rows and T columns , where T is the number of MCMC iterations.}

\item{iteration}{The number of MCMC chains wish to run}

\item{C.init}{A hyperparameter}

\item{pi.alpha}{A hyperparameter}

\item{seed}{An initial seed for random number generator.}
}
\value{
A matrix of clustering output (cluster assignment), 
with G rows and I columns, where I is equal to iteration/thin.
}
\description{
Function to run DPM part of the model
}
\examples{
\dontrun{
## After completing the MCMC step	
data(test.data)
data(test.label)
Data.list <- test.data
X.list <-  test.label
G <- nrow(Data.list[[1]])
K <- length(Data.list)
libsize <- lapply(Data.list,colSums)
es_seq =function (y,X,lib) {
 y=array(y)
 v1=log((y[which(X==1)]+1)/(lib[which(X==1)]))
 v2=log((y[which(X==0)]+1)/(lib[which(X==0)]))
 u=mean(v1) - mean(v2)
 return(u)
}
## Calculate the observed effect size (get directionality)
beta.obs<-matrix(rep(0,G*K),nrow=G,ncol=K) 
for (g in 1:G){
 for (k in 1:K){
   lib<-libsize[[k]]
   beta.obs[g,k]<-es_seq(y=Data.list[[k]][g,],X=X.list[[k]],lib=lib)
 }
}
## Only interested in the clustering of the first 300 DE genes
beta.obs.de <- beta.obs[1:300,]
delta.de <- MCMC.out[['Delta']][1:(300*3),]
C.init <- 10 
pi.alpha<- 2  
thin <- 20
## Run the DPM part  
cluster.out <- DPM(Beta.obs = beta.obs.de, Delta = delta.de,iteration = iteration, 
thin = thin, C.init = C.init, pi.alpha = pi.alpha,  seed=12345)
cluster.top <- cluster.out[,-c(1:(burnin/thin+1))] ## remove the burnin period
rownames(cluster.top) <- paste('gene',1:300,sep='')	
## Performs consensus clustering to summarize posterior
library(ConsensusClusterPlus)  
copy.upper.lower <- function(m) 
{
 m[lower.tri(m)] <- t(m)[lower.tri(m)]
 m
}
mydist <- function(y) {
 diss.mat <- matrix(,nrow=nrow(y),ncol=nrow(y))
 rownames(diss.mat) <- colnames(diss.mat) <- rownames(y)
 diag(diss.mat) <- 1
 for (i in 1:nrow(diss.mat)) {
   for (j in i:ncol(diss.mat)){
     diss.mat[i,j] <- sum(y[i,]==y[j,])/ncol(y)    
   }
 }
 diss.mat <- copy.upper.lower(diss.mat)
return(1-diss.mat)
}
results = ConsensusClusterPlus(d=t(cluster.top),maxK=6,reps=50,pItem=0.8,pFeature=1,
    title="Consensus Clustering Result",clusterAlg="hc",innerLinkage="ward.D2",
    finalLinkage="ward.D2", distance="mydist",seed=1262118388.71279,plot="png") 
}
}

