% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ParallelMCMC.R
\name{parMCMC}
\alias{parMCMC}
\title{Function to run parallel MCMC chain}
\usage{
parMCMC(Data.list, X.list, iteration, chunks, lambda.mean = 0,
  lambda.var = 10, eta.mean = 0, eta.var = 10, m.mean = 0, m.var = 10,
  seed = 12345)
}
\arguments{
\item{Data.list}{A list of K elements, where K is the number of studies, 
each element is an RNAseq data matrix with G rows and N 
columns, where G is number of genes and N is the sample size.
Genes are matched across all studies.}

\item{X.list}{A list of K elements, each element includes is a phenotypic
condition of the corresponding samples, with case=1, control=0.}

\item{iteration}{The number of MCMC chains wish to run}

\item{chunks}{The number of data chunks to split into (= number of CPUs called in snowfall)}

\item{lambda.mean}{A hyperparameter}

\item{lambda.var}{A hyperparameter}

\item{eta.mean}{A hyperparameter}

\item{eta.var}{A hyperparameter}

\item{m.mean}{A hyperparameter}

\item{m.var}{A hyperparameter}

\item{seed}{An initial seed for random number generator.}
}
\value{
A list of three components:
\itemize{
\item{Delta}{ A output matrix of DE indicator estimate delta (Reordered according to gene.name).}
\item{Beta}{ A output matrix of effect size estimate beta (Reordered according to gene.name).}
\item{Gene.Name}{ Reordered gene names according to random split of original dataset; if the original dataset has no gene names, we will simply use gene(RowNumber) to denote the gene name, e.g. gene1 refers to the first gene.}
}
}
\description{
Function to run parallel MCMC chain
}
\examples{
\dontrun{
data(test.data)
data(test.label)
Data.list <- test.data
X.list <- test.label
G <- nrow(Data.list[[1]])
K <- length(Data.list)
lambda.mean<-0
lambda.var<- 10
eta.mean<- 0
eta.var<- 10 
m.mean<- 0
m.var<- 10
iteration <- 2000	
burnin <- 500
chunks <- 2	
MCMC.out <- parMCMC(Data.list=Data.list,X.list=X.list,iteration=iteration,
                   chunks = chunks,
                  lambda.mean=lambda.mean, lambda.var=lambda.var, 
                   eta.mean=eta.mean, eta.var=eta.var, 
                   m.mean=m.mean, m.var=m.var, seed=12345) 
delta <- MCMC.out[['Delta']]
gene.name <- MCMC.out[['Gene.Name']]
delta.mean <- apply(delta[,-c(1:burnin)],1,mean)
delta.mat <- matrix(delta.mean,nrow=G,ncol=K,byrow=T)
rownames(delta.mat) <- gene.name
### Don't forget to turn the output back to the original gene order as in Data.list:
delta.mat.order <- delta.mat[rownames(Data.list[[1]]),]
}
}

